@@ -14,6 +14,7 @@ from autostar.config.datapaths import ref_dir, star_name_format, StarName, Strin
 
 
 deg_per_mas = 1.0 / (1000.0 * 60.0 * 60.0)
+gaia_dr3_ref = "Gaia DR3 Gaia Collaboration et al. (2016b) and Gaia Collaboration et al. (2022k)"
 
 
 def simple_job_text(dr_num, sub_list):
@@ -25,6 +26,8 @@ def simple_job_text(dr_num, sub_list):
 
 
 class GaiaLib:
+    gaia_dr3_ref = gaia_dr3_ref
+
     def __init__(self, simbad_lib=None, simbad_go_fast=False, verbose=True):
         self.verbose = verbose
         self.simbad_go_fast = simbad_go_fast
@@ -108,7 +111,10 @@ class GaiaLib:
             dr_number = int(gaia_name_type.replace("gaia dr", "").strip())
             _gaia_ids, gaia_params_dict = gaia_params_dicts[gaia_hypatia_name]
             gaia_params_dict_keys = set(gaia_params_dict.keys())
-            ref_str = "Gaia Data Release " + str(dr_number)
+            if dr_number == 3:
+                ref_str = self.gaia_dr3_ref
+            else:
+                ref_str = "Gaia Data Release " + str(dr_number)
             params_dicts = {}
             param_names_found = set()
             # handling for the distance from the Bailer-Jones Catalog
@@ -128,6 +134,23 @@ class GaiaLib:
                     lower_error = None
                 if lower_error is not None or upper_error is not None:
                     params_dicts['dist']['err'] = (lower_error, upper_error)
+            elif "distance_gspphot" in gaia_params_dict_keys:
+                params_dicts['dist'] = {}
+                param_names_found.add('dist')
+                params_dicts['dist']['value'] = gaia_params_dict["distance_gspphot"]
+                params_dicts['dist']['ref'] = self.gaia_dr3_ref
+                params_dicts['dist']['units'] = self.gaia_query.param_to_units["distance_gspphot"]
+                if "distance_gspphot_upper" in gaia_params_dict_keys:
+                    upper_error = gaia_params_dict["distance_gspphot_upper"] - gaia_params_dict["distance_gspphot"]
+                else:
+                    upper_error = None
+                if "distance_gspphot_lower" in gaia_params_dict_keys:
+                    lower_error = gaia_params_dict["distance_gspphot_lower"] - gaia_params_dict["distance_gspphot"]
+                else:
+                    lower_error = None
+                if lower_error is not None or upper_error is not None:
+                    params_dicts['dist']['err'] = (lower_error, upper_error)
+
             if "teff_val" in gaia_params_dict_keys:
                 params_dicts['teff'] = {}
                 param_names_found.add('teff')
@@ -144,6 +167,22 @@ class GaiaLib:
                     lower_error = None
                 if lower_error is not None or upper_error is not None:
                     params_dicts['teff']['err'] = (lower_error, upper_error)
+            elif "teff_gspphot" in gaia_params_dict_keys:
+                params_dicts['teff'] = {}
+                param_names_found.add('teff')
+                params_dicts['teff']['value'] = gaia_params_dict["teff_gspphot"]
+                params_dicts['teff']['ref'] = ref_str
+                params_dicts['teff']['units'] = self.gaia_query.param_to_units["teff_gspphot"]
+                if "teff_gspphot_upper" in gaia_params_dict_keys:
+                    upper_error = gaia_params_dict["teff_gspphot_upper"] - gaia_params_dict["teff_gspphot"]
+                else:
+                    upper_error = None
+                if "teff_gspphot_lower" in gaia_params_dict_keys:
+                    lower_error = gaia_params_dict["teff_gspphot_lower"] - gaia_params_dict["teff_gspphot"]
+                else:
+                    lower_error = None
+                if lower_error is not None or upper_error is not None:
+                    params_dicts['teff']['err'] = (lower_error, upper_error)
             for param_key in gaia_params_dict_keys - self.special_case_params:
                 if "_error" in param_key:
                     param_name = param_key.replace("_error", "")
@@ -284,7 +323,14 @@ class GaiaQuery:
                                        "radial_velocity", "radial_velocity_error",
                                        "teff_val", "teff_percentile_lower", "teff_percentile_upper",
                                        "r_est", "r_lo", "r_hi"}
-        self.astro_query_dr3_params = self.astro_query_dr2_params
+        self.astro_query_dr3_params = {"ra", "ra_error", "dec", "dec_error", "ref_epoch", "source_id",
+                                       "parallax", "parallax_error",
+                                       "pmra", "pmra_error", "pmdec", "pmdec_error", "duplicated_source",
+                                       "phot_g_mean_flux", "phot_g_mean_flux_error",
+                                       "phot_g_mean_mag",
+                                       "radial_velocity", "radial_velocity_error",
+                                       "teff_gspphot", "teff_gspphot_lower", "teff_gspphot_upper",
+                                       "distance_gspphot", "distance_gspphot_lower", "distance_gspphot_upper"}
         self.param_to_units = {"ra_epochJ2000": "deg", "ra_error": "deg", 'dec_epochJ2000': 'deg', "dec_error": 'deg',
                                "ref_epoch": 'Julian Years', 'parallax': 'mas', "parallax_error": "mas",
                                "pmra": 'mas/year', "pmra_error": "mas/year",
@@ -292,8 +338,10 @@ class GaiaQuery:
                                "phot_g_mean_flux": "e-/s", "phot_g_mean_mag": 'mag',
                                "radial_velocity": "km/s",
                                "teff_val": "K", "teff_percentile_lower": "K", "teff_percentile_upper": "K",
+                               "teff_gspphot": "K", "teff_gspphot_lower": "K", "teff_gspphot_upper": "K",
                                "dist_parallax": "[pc]",
-                               "r_est": "[pc]", "r_lo": "[pc]", "r_hi": "[pc]", 'dist': '[pc]'}
+                               "r_est": "[pc]", "r_lo": "[pc]", "r_hi": "[pc]", 'dist': '[pc]',
+                               "distance_gspphot": "[pc]", "distance_gspphot_lower": "[pc]", "distance_gspphot_upper": "[pc]"}
         self.params_with_units = set(self.param_to_units.keys())
 
     def astroquery_get_job(self, job, dr_num=2):
